@@ -5,20 +5,37 @@ import os
 import sys
 from dataclasses import dataclass
 from enum import IntEnum
+from importlib import resources
 from importlib.metadata import entry_points, version
-from typing import Any, List, Optional
+from typing import Any, Dict, List, Optional, TypeVar
 
 import requests
 import rich.console
 import yarl
-
-from gbpcli import queries
-
-from . import queries
+from rich.theme import Theme
 
 LOCAL_TIMEZONE = datetime.datetime.now().astimezone().tzinfo
 DEFAULT_URL = os.getenv("BUILD_PUBLISHER_URL", "http://localhost/")
 
+ColorMap = Dict[str, str]
+
+DEFAULT_THEME: ColorMap = {
+    "build_id": "bold",
+    "header": "bold",
+    "keep": "yellow",
+    "machine": "blue",
+    "note": "default",
+    "note_flag": "blue",
+    "package": "magenta",
+    "published": "bold green",
+    "tag": "yellow",
+    "timestamp": "default",
+    "yes": "green",
+    "no": "default",
+    "added": "green",
+    "removed": "red",
+}
+
 
 class APIError(Exception):
     """When an error is returned by the REST API"""
@@ -28,6 +45,30 @@ class APIError(Exception):
         self.data = data
 
 
+class Queries:
+    """Python interface to raw queries/*.graphql files"""
+
+    def __getattr__(self, name: str) -> str:
+        query_file = resources.files("gbpcli") / "queries" / f"{name}.graphql"
+        try:
+            return query_file.read_text(encoding="UTF-8")
+        except FileNotFoundError:
+            raise AttributeError(name) from None
+
+    def to_dict(self) -> dict[str, str]:
+        """Return the queries as a dict"""
+        files = (resources.files("gbpcli") / "queries").iterdir()
+
+        return {
+            filename.name[:-8]: getattr(self, filename.name[:-8])
+            for filename in files
+            if filename.name.endswith(".graphql")
+        }
+
+
+queries = Queries()
+
+
 @dataclass
 class BuildInfo:
     """Metatada about a Build
@@ -49,6 +90,10 @@ class Package:
     """A (binary) package"""
 
     cpv: str
+    build_time: datetime.datetime
+
+
+T = TypeVar("T", bound="Build")
 
 
 @dataclass
@@ -66,12 +111,45 @@ class Build:
         return f"{self.machine}.{self.number}"
 
     @classmethod
-    def from_id(cls, build_id: str, **kwargs):
+    def from_id(cls: type[T], build_id: str, **kwargs) -> T:
         """Create from GBP build id"""
         parts = build_id.partition(".")
 
         return cls(machine=parts[0], number=int(parts[2]), **kwargs)
 
+    @classmethod
+    def from_api_response(cls: type[T], api_response) -> T:
+        """Return a Build with BuildInfo given the response from the API"""
+        completed = api_response.get("completed")
+        submitted = api_response["submitted"]
+        fromisoformat = datetime.datetime.fromisoformat
+        built = api_response.get("built")
+
+        if api_response.get("packagesBuilt", None) is None:
+            packages_built = None
+        else:
+            packages_built = [
+                Package(
+                    cpv=i["cpv"],
+                    build_time=datetime.datetime.fromtimestamp(i.get("buildTime", 0)),
+                )
+                for i in api_response["packagesBuilt"]
+            ]
+
+        return cls.from_id(
+            api_response["id"],
+            info=BuildInfo(
+                api_response.get("keep"),
+                published=api_response.get("published"),
+                tags=api_response.get("tags"),
+                note=api_response.get("notes"),
+                submitted=fromisoformat(submitted),
+                completed=fromisoformat(completed) if completed is not None else None,
+                built=fromisoformat(built) if built is not None else None,
+            ),
+            packages_built=packages_built,
+        )
+
 
 class Status(IntEnum):
     """Diff status"""
@@ -117,11 +195,22 @@ class GBP:
         response_json = response.json()
         return response_json.get("data"), response_json.get("errors")
 
-    def machines(self) -> list[tuple[str, int]]:
+    def machines(self) -> list[tuple[str, int, dict]]:
         """Handler for subcommand"""
         data = self.check(queries.machines)
 
-        return [(i["machine"], i["buildCount"]) for i in data["machines"]]
+        return [
+            (i["machine"], i["buildCount"], i["latestBuild"]) for i in data["machines"]
+        ]
+
+    def machine_names(self) -> list["str"]:
+        """Return the list of machine names
+
+        Machines having builds.
+        """
+        machines = self.check(queries.machine_names)["machines"]
+
+        return [machine["machine"] for machine in machines]
 
     def publish(self, build: Build):
         """Publish the given build"""
@@ -167,7 +256,7 @@ class GBP:
         builds = data["builds"]
         builds.reverse()
 
-        return [self.api_to_build(i) for i in builds]
+        return [Build.from_api_response(i) for i in builds]
 
     def diff(
         self, machine: str, left: int, right: int
@@ -177,8 +266,8 @@ class GBP:
         data = self.check(queries.diff, variables)
 
         return (
-            self.api_to_build(data["diff"]["left"]),
-            self.api_to_build(data["diff"]["right"]),
+            Build.from_api_response(data["diff"]["left"]),
+            Build.from_api_response(data["diff"]["right"]),
             [
                 Change(item=i["item"], status=getattr(Status, i["status"]))
                 for i in data["diff"]["items"]
@@ -205,7 +294,7 @@ class GBP:
                 raise APIError(errors, data)
             return None
 
-        return self.api_to_build(data["build"])
+        return Build.from_api_response(data["build"])
 
     def build(self, machine: str) -> str:
         """Schedule a build"""
@@ -244,7 +333,7 @@ class GBP:
         response = self.check(query, {"machine": machine, "key": key})
         builds = response["searchNotes"]
 
-        return [self.api_to_build(i) for i in builds]
+        return [Build.from_api_response(i) for i in builds]
 
     def tag(self, build: Build, tag: str) -> None:
         """Add the given tag to the build"""
@@ -256,35 +345,6 @@ class GBP:
         """Remove the tag from the given machine"""
         self.check(queries.untag_build, {"machine": machine, "tag": tag})
 
-    @staticmethod
-    def api_to_build(api_response) -> Build:
-        """Return a Build with BuildInfo given the response from the API"""
-        completed = api_response.get("completed")
-        submitted = api_response["submitted"]
-        fromisoformat = datetime.datetime.fromisoformat
-        built = api_response.get("built")
-
-        if api_response.get("packagesBuilt", None) is None:
-            packages_built = None
-        else:
-            packages_built = [
-                Package(cpv=i["cpv"]) for i in api_response["packagesBuilt"]
-            ]
-
-        return Build.from_id(
-            api_response["id"],
-            info=BuildInfo(
-                api_response.get("keep"),
-                published=api_response.get("published"),
-                tags=api_response.get("tags"),
-                note=api_response.get("notes"),
-                submitted=fromisoformat(submitted),
-                completed=fromisoformat(completed) if completed is not None else None,
-                built=fromisoformat(built) if built is not None else None,
-            ),
-            packages_built=packages_built,
-        )
-
     def check(self, query: str, variables: dict[str, Any] = None) -> dict:
         """Run query and raise exception if there are errors"""
         data, errors = self.query(query, variables)
@@ -296,6 +356,7 @@ class GBP:
 
 def build_parser() -> argparse.ArgumentParser:
     """Set command-line arguments"""
+    usage = "Command-line interface to Gentoo Build Publisher\n\nCommands:\n\n"
     parser = argparse.ArgumentParser(prog="gbp")
     parser.add_argument(
         "--version", action="version", version=f"gbpcli {version('gbpcli')}"
@@ -322,12 +383,52 @@ def build_parser() -> argparse.ArgumentParser:
             description=module.__doc__,
             formatter_class=argparse.RawTextHelpFormatter,
         )
+        usage = f"{usage}  * {entry_point.name} - {module.handler.__doc__}\n"
         module.parse_args(subparser)
         subparser.set_defaults(func=module.handler)
 
+    parser.usage = usage
+
     return parser
 
 
+def get_colormap_from_string(string: str) -> ColorMap:
+    """Given the text sring return a gbp ColorMap
+
+    String is expected to be a colon-delimited (":") set of name=value pairs. So for
+    example:
+
+        "build_id=bold:header=bold:keep=yellow:machine=blue"
+
+    Values are stripped of whitespace. If the fields cannot be parsed a `ValueError` is
+    raised.  Empty names/values are ignored as are unrecognized names.
+    """
+    colormap = DEFAULT_THEME.copy()
+    error = ValueError(f"Invalid color map: {string!r}")
+
+    if not string:
+        return colormap
+
+    for assignment in string.split(":"):
+        if not assignment:
+            continue
+        try:
+            name, value = assignment.split("=")
+        except ValueError:
+            raise error from None
+
+        name = name.strip()
+        name = name.strip()
+
+        if not name or not value:
+            continue
+
+        if name in colormap:
+            colormap[name] = value.strip()
+
+    return colormap
+
+
 def main(argv: list[str] | None = None) -> int:
     """Main entry point"""
     if argv is None:
@@ -344,8 +445,17 @@ def main(argv: list[str] | None = None) -> int:
     gbp = GBP(args.url)
 
     force_terminal = {"always": True, "never": False}.get(args.color, None)
+
+    try:
+        console_theme = get_colormap_from_string(os.getenv("GBPCLI_COLORS", ""))
+    except ValueError:
+        console_theme = DEFAULT_THEME
+
     console = rich.console.Console(
-        force_terminal=force_terminal, color_system="auto", highlight=False
+        force_terminal=force_terminal,
+        color_system="auto",
+        highlight=False,
+        theme=Theme(console_theme),
     )
 
     try:
