@@ -8,7 +8,7 @@ from gbpcli import GBP
 
 
 def handler(args: argparse.Namespace, gbp: GBP, console: Console) -> int:
-    """Handler for subcommand"""
+    """Show the latest build number for a machine"""
     latest_build = gbp.latest(args.machine)
     if not latest_build:
         print("No builds exist for the given machine", file=sys.stderr)
