@@ -8,7 +8,7 @@ from gbpcli import GBP, utils
 
 
 def handler(args: argparse.Namespace, gbp: GBP, console: Console) -> int:
-    """Handler for subcommand"""
+    """List a build's packages"""
     build = utils.resolve_build_id(args.machine, args.number, gbp)
     packages = gbp.packages(build)
 
@@ -17,7 +17,7 @@ def handler(args: argparse.Namespace, gbp: GBP, console: Console) -> int:
         return 1
 
     for package in packages:
-        console.print(package, highlight=False)
+        console.print(f"[package]{package}[/package]")
 
     return 0
 
