@@ -7,7 +7,7 @@ from gbpcli import GBP, Build
 
 
 def handler(args: argparse.Namespace, gbp: GBP, _console: Console) -> int:
-    """Handler for the pull subcommand"""
+    """Pull a build"""
     build = Build(machine=args.machine, number=args.number)
 
     gbp.pull(build)
